# Rat Connectome
Python API for neuroVIISAS Rat Connectome Project

```
Schmitt, O. and Eipert, P. (2012). 
neuroVIISAS: Approaching Multiscale Simulation of the Rat Connectome
Neuroinformatics. 2012 Jul;10(3):243-67. doi: 10.1007/s12021-012-9141-6
```

## How to use
> from ratconn import Interface
> itf = Interface()
Input ROI = None
Side = searchAll
Search option = starts
Abbr. = False

> itf.search('Thalamus')
> itf.results

